@@ -1,13 +1,15 @@
 package App::SpamcupNG::UserAgent;
 use warnings;
 use strict;
+use Carp qw(croak);
 use LWP::UserAgent 6.60;
-use HTTP::Request 6.35;
+use HTTP::Request 6.36;
 use Log::Log4perl 1.54 qw(get_logger :levels);
 use HTTP::CookieJar::LWP 0.012;
 use Mozilla::PublicSuffix v1.0.6;
+use HTTP::Request::Common qw(POST);
 
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 =head1 NAME
 
@@ -39,13 +41,16 @@ sub new {
     die 'The parameter version is required' unless ($version);
 
     my $self = {
-        name             => 'spamcup user agent',
+        name             => 'SpamcupNG user agent',
         version          => $version,
         members_url      => 'https://members.spamcop.net/',
         code_login_url   => 'https://www.spamcop.net/?code=',
         report_url       => 'https://www.spamcop.net/sc?id=',
+        form_login_url   => 'https://www.spamcop.net/mcgi',
+        domain           => 'https://www.spamcop.net/',
+        password_field   => 'password',
         current_base_url => undef
-        };
+    };
 
     bless $self, $class;
 
@@ -53,7 +58,10 @@ sub new {
         agent             => ( $self->{name} . '/' . $version ),
         protocols_allowed => ['https'],
         cookie_jar        => HTTP::CookieJar::LWP->new
-        );
+    );
+
+    # for form based authentication
+    push @{ $ua->requests_redirectable }, 'POST';
     $self->{user_agent} = $ua;
     return $self;
 }
@@ -74,42 +82,131 @@ sub user_agent {
 
 Execute the login to Spamcop website.
 
+If form based authentication is in use, it will login just once and return the
+response of HTTP GET to Spamcop root URL.
+
 Expect as parameters:
 
-- id: the ID of a Spamcop account. - password: the password of a Spamcop
-account.
+=over
 
-Returns the HTML content as a scalar reference.
+=item *
+
+id: the ID of a Spamcop account.
+
+=item *
+
+password: the password of a Spamcop account.
+
+=back
+
+Returns the HTTP response (HTML content) as a scalar reference.
 
 =cut
 
+# copied from HTTP::Request::as_string
+sub _request_line {
+    my $request  = shift;
+    my $req_line = $request->method || "-";
+    my $uri      = $request->uri;
+    $uri = ( defined $uri ) ? $uri->as_string : "-";
+    $req_line .= " $uri";
+    my $proto = $request->protocol;
+    $req_line .= " $proto" if $proto;
+    return $req_line;
+}
+
 sub _redact_auth_req {
     my ( $self, $request ) = @_;
-    my @lines    = split( "\n", $request->as_string );
-    my $secret   = ( split( /\s/, $lines[1] ) )[2];
-    my $redacted = '*' x length($secret);
-    $lines[1] =~ s/$secret/$redacted/;
+    my @lines;
+
+    return $request->as_string if ( $self->_is_authenticated );
+
+    if ( $request->method eq 'POST' ) {
+        push( @lines, _request_line($request) );
+        push( @lines, $request->headers_as_string );
+        my @params = split( '&', $request->content );
+        my %params
+            = map { my @tmp = split( '=', $_ ); $tmp[0] => $tmp[1] } @params;
+        croak(    'Unexpected request content, missing '
+                . $self->{password_field}
+                . ' field' )
+            unless exists( $params{ $self->{password_field} } );
+        my $redacted = '*' x length( $params{ $self->{password_field} } );
+        $params{ $self->{password_field} } = $redacted;
+
+        while ( my ( $key, $value ) = each %params ) {
+            push( @lines, "$key=$value" );
+        }
+    }
+    else {
+        @lines = split( "\n", $request->as_string );
+        my $secret   = ( split( /\s/, $lines[1] ) )[2];
+        my $redacted = '*' x length($secret);
+        $lines[1] =~ s/$secret/$redacted/;
+    }
+
     return join( "\n", @lines );
 }
 
+sub _dump_cookies {
+    my $self    = shift;
+    my @cookies = $self->{user_agent}
+        ->cookie_jar->dump_cookies( { persistent => 1 } );
+    my $counter = 0;
+    my @dump;
+
+    foreach my $cookie (@cookies) {
+        push( @dump, ( $counter . ' => ' . $cookie ) );
+    }
+
+    return join( "\n", @dump );
+}
+
+sub _is_authenticated {
+    my $self = shift;
+    return $self->{user_agent}->cookie_jar->cookies_for( $self->{domain} );
+}
+
 sub login {
-    my ( $self, $id, $password ) = @_;
+    my ( $self, $id, $password, $is_basic ) = @_;
+    $is_basic = 0 unless ( defined($is_basic) );
     my $logger = get_logger('SpamcupNG');
     my $request;
 
-# TODO: check if the cookie is still valid before trying to login again
-# TODO: implement HTML form authentication
-#$logger->info( 'Available cookies before auth: ' . Dumper( $self->{user_agent}->cookie_jar->dump_cookies ) );
+    if ( $logger->is_debug ) {
+        $logger->debug( "Initial cookies:\n" . $self->_dump_cookies );
+    }
 
-    if ($password) {
-        $request = HTTP::Request->new( GET => $self->{members_url} );
-        $request->authorization_basic( $id, $password );
+    if ( $self->_is_authenticated ) {
+        $logger->info('Already authenticated');
+        $request = HTTP::Request->new( GET => $self->{domain} );
     }
     else {
-        $request = HTTP::Request->new(
-            GET => $self->{code_login_url} . $id );
+        if ($password) {
+
+            if ($is_basic) {
+                $request = HTTP::Request->new( GET => $self->{members_url} );
+                $request->authorization_basic( $id, $password );
+            }
+            else {
+                $request = POST $self->{form_login_url},
+                    [
+                    username                => $id,
+                    $self->{password_field} => $password,
+                    duration                => '+12h',
+                    action                  => 'cookielogin',
+                    returnurl               => '/'
+                    ];
+            }
+        }
+        else {
+            $request
+                = HTTP::Request->new( GET => $self->{code_login_url} . $id );
+        }
     }
 
+    $request->protocol('HTTP/1.1');
+
     if ( $logger->is_debug() ) {
         $logger->debug(
             "Request details:\n" . ( $self->_redact_auth_req($request) ) );
@@ -119,9 +216,10 @@ sub login {
 
     if ( $logger->is_debug() ) {
         $logger->debug( "Got response:\n" . $response->as_string );
+        $logger->debug(
+            "After authentication cookies:\n" . $self->_dump_cookies );
     }
 
-#$logger->info( 'Available cookies after auth: ' . Dumper( $self->{user_agent}->cookie_jar->dump_cookies ) );
     return \( $response->content ) if ( $response->is_success );
 
     my $status = $response->status_line();
@@ -131,13 +229,18 @@ sub login {
     }
     else {
         $logger->warn($status);
+
+        if ( ($password) and ( $is_basic == 0 ) ) {
+            $logger->warn('Retrying with basic authentication');
+            return $self->login( $id, $password, 1 );
+        }
+
         $logger->fatal(
-            'Cannot connect to server or invalid credentials. Please verify your username and password and try again.'
-            );
+'Cannot connect to server or invalid credentials. Please verify your username and password and try again.'
+        );
     }
 
     return undef;
-
 }
 
 =head2 spam_report
